@@ -23,10 +23,7 @@ from boltons.ecoutils import get_profile
 
 from .xbar import fix_environment
 
-# Canonical name of the CLI.
-CLI_NAME = "mpm"
-
-__version__ = "4.3.0"
+__version__ = "4.4.0"
 """ Examples of valid version strings according :pep:`440#version-scheme`:
 
 .. code-block:: python
@@ -40,6 +37,15 @@ __version__ = "4.3.0"
 """
 
 
+# Canonical name of the CLI.
+CLI_NAME = "mpm"
+
+
+# Some CLI printing constants.
+PROMPT = "► "
+INDENT = " " * len(PROMPT)
+
+
 # Environment data.
 env_data = get_profile(scrub=True)
 
