@@ -16,6 +16,7 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 import os
+import re
 from pathlib import Path
 from shutil import which
 from textwrap import dedent, indent, shorten
@@ -26,7 +27,7 @@ from boltons.iterutils import flatten
 from boltons.strutils import strip_ansi
 from boltons.typeutils import classproperty
 
-from . import logger
+from . import INDENT, PROMPT, logger
 from .platform import CURRENT_OS_ID
 from .version import parse_version
 from .xbar import run
@@ -48,9 +49,8 @@ class CLIError(Exception):
 
     def __str__(self):
         """Human-readable error."""
-        margin = " " * 2
-        indented_output = indent(str(self.output), margin)
-        indented_error = indent(str(self.error), margin)
+        indented_output = indent(str(self.output), INDENT)
+        indented_error = indent(str(self.error), INDENT)
         return indent(
             dedent(
                 f"""
@@ -60,7 +60,7 @@ class CLIError(Exception):
             Error:
             {indented_error}"""
             ),
-            margin,
+            INDENT,
         )
 
     def __repr__(self):
@@ -80,6 +80,15 @@ class PackageManager:
     # Version requirement specifier.
     requirement = None
 
+    # List of options to use to get the version from the package manager.
+    version_cli_options = ["--version"]
+
+    # Regular expression used to extract the version number from the result of the CLI
+    # run with the options above. It doesn't matter if the regex returns unsanitized
+    # and crappy string. The ``version()`` method will clean and normalized it.
+    # By default match the first part that is space-separated.
+    version_regex = r"(?P<version>\S+)"
+
     # List of additional path to help mpm hunt down the package manager CLI.
     # Should be a list of strings whose order dictatate the search sequence.
     # Most of the time unnecessay: the `cli_path()` method works well on all
@@ -97,6 +106,9 @@ class PackageManager:
     # possessing their own auto-update mecanism.
     ignore_auto_updates = True
 
+    # Do not actually perform any action, just simulate CLI calls.
+    dry_run = False
+
     def __init__(self):
         # Log of all encountered CLI errors.
         self.cli_errors = []
@@ -108,7 +120,7 @@ class PackageManager:
         This ID must be unique among all package manager definitions and
         lower-case as they're used as feature flags for the :command:`mpm` CLI.
         """
-        return cls.__name__.lower()
+        return cls.__name__.lower().replace("_", "-")
 
     @classproperty
     def name(cls):
@@ -156,7 +168,7 @@ class PackageManager:
             cli_path = which(name, mode=os.F_OK, path=env_path)
             if cli_path:
                 break
-            logger.debug(f"{name!r} CLI not found.")
+            logger.debug(f"{name} CLI not found.")
 
         if not cli_path:
             return
@@ -170,26 +182,30 @@ class PackageManager:
         elif not cli_path.is_file():
             logger.warning(f"{cli_path} is not a file.")
         else:
-            logger.debug(f"{name!r} CLI found at {cli_path}")
+            logger.debug(f"{name} CLI found at {cli_path}")
 
         return cli_path
 
-    def get_version(self):
-        """Invoke the manager and extract its own reported version.
-
-        It does matter if this method return unsanitized and crappy string. The
-        ``version()`` method below will clean and normalized it.
-        """
-        raise NotImplementedError
-
     @cachedproperty
     def version(self):
-        """Parsed and normalized package manager's own version.
+        """Invoke the manager and extract its own reported version string.
 
-        Returns an instance of `TokenizedString`.
+        Returns a parsed and normalized version in the form of a `TokenizedString`
+        instance.
         """
         if self.executable:
-            return self.get_version()
+            # Invoke the manager.
+            output = self.run_cli(self.version_cli_options, force_exec=True)
+
+            # Extract the version with the regex.
+            if output:
+                version_string = (
+                    re.compile(self.version_regex, re.MULTILINE | re.VERBOSE)
+                    .search(output)
+                    .groupdict()
+                ).get("version")
+                logger.debug(f"Extracted version: {version_string}")
+                return parse_version(version_string)
 
     @cachedproperty
     def supported(self):
@@ -234,24 +250,30 @@ class PackageManager:
         """
         return bool(self.supported and self.cli_path and self.executable and self.fresh)
 
-    def run(self, *args, dry_run=False):
-        """Run a shell command, return the output and keep error message.
+    def run(self, *args):
+        """Run a shell command, return the output and accumulate error messages.
 
-        Removes ANSI escape codes, and returns ready-to-use strings.
+        args is allowed to be a nested structure of iterables, in which case it will
+        be flatten, then each item within casted to strings.
+
+        Internally reuse the run() method from the xbar plugin, but adds logs at the
+        appropriate level, removes ANSI escape codes, returns ready-to-use strings, and
+        takes --dry-run and --stop-on-error into account.
         """
-        # Serialize Path objects to strings.
+        # Casting to string helps serialize Path and Version objects.
         args = list(map(str, flatten(args)))
         args_str = click.style(" ".join(args), fg="white")
-        logger.debug(f"► {args_str}")
+        cli_msg = f"{PROMPT}{args_str}"
 
         code = 0
         output = None
         error = None
 
-        if not dry_run:
-            code, output, error = run(*args)
+        if self.dry_run:
+            logger.warning(f"Dry-run: {cli_msg}")
         else:
-            logger.warning("Dry-run: skip execution of command.")
+            logger.debug(cli_msg)
+            code, output, error = run(*args)
 
         # Normalize messages.
         if error:
@@ -261,6 +283,14 @@ class PackageManager:
             output = strip_ansi(output)
             output = output if output else None
 
+        # Log <stdout> and <stderr> output.
+        if output:
+            logger.debug(indent(output, INDENT))
+        if error:
+            # Non-fatal error messages are logged as warnings.
+            log_func = logger.error if code else logger.warning
+            log_func(indent(error, INDENT))
+
         # Non-successful run.
         if code and error:
             # Produce an exception and eventually raise it.
@@ -270,33 +300,40 @@ class PackageManager:
             # Accumulate errors.
             self.cli_errors.append(exception)
 
-        # Log <stdout> and <stderr> output.
-        if output:
-            logger.debug(indent(output, "  "))
-        if error:
-            # Non-fatal error messages are logged as warnings.
-            log_func = logger.error if code else logger.warning
-            log_func(indent(error, "  "))
-
         return output
 
-    def run_cli(self, *args, dry_run=False):
-        """Like the ``run`` method above, but execute the binary pointed to by
-        the ``cli_path`` property set in the current instance.
+    def run_cli(self, *args, force_exec=False):
+        """Shortcut utility to the ``run`` method above, that is explicitly using the
+        binary set by the ``cli_path`` property.
+
+        Also offer the possibility to force the execution and completion of the command
+        regardless of the instance --dry-run and --stop-on-error user options.
         """
-        return self.run(self.cli_path, args, dry_run=dry_run)
+        # Temporarily replace --dry-run and --stop-on-error user options with our own.
+        if force_exec:
+            user_options = (self.dry_run, self.stop_on_error)
+            self.dry_run, self.stop_on_error = False, False
+
+        # Execute the command.
+        output = self.run(self.cli_path, args)
+
+        # Restore user options for --dry-run and --stop-on-error.
+        if force_exec:
+            self.dry_run, self.stop_on_error = user_options
+
+        return output
 
     def sync(self):
         """Refresh local manager metadata from remote repository."""
         if self.sync.__func__.__qualname__ == PackageManager.sync.__qualname__:
-            logger.warning(f"Sync not implemented for {self.id}.")
+            logger.warning(f"{self.id} does not implement sync command.")
             return
         logger.info(f"Sync {self.id} package info...")
 
     def cleanup(self):
         """Remove left-overs and unused packages."""
         if self.cleanup.__func__.__qualname__ == PackageManager.cleanup.__qualname__:
-            logger.warning(f"Cleanup not implemented for {self.id}.")
+            logger.warning(f"{self.id} does not implement cleanup command.")
             return
         logger.info(f"Cleanup {self.id}...")
 
@@ -316,14 +353,12 @@ class PackageManager:
         package ID, name, version and a boolean indicating if the match is
         exact or partial.
         """
-        if self.search.__func__.__qualname__ == PackageManager.search.__qualname__:
-            logger.warning(f"Search not implemented for {self.id}.")
-            return {}
+        raise NotImplementedError
 
     def install(self, package_id):
         """Install one package and one only."""
         if self.install.__func__.__qualname__ == PackageManager.install.__qualname__:
-            logger.warning(f"Install not implemented for {self.id}.")
+            logger.warning(f"{self.id} does not implement install command.")
             return
         logger.info(f"Install {package_id} package from {self.id}...")
 
@@ -341,35 +376,28 @@ class PackageManager:
         """Return a shell-compatible full-CLI to upgrade a package."""
         raise NotImplementedError
 
-    def upgrade(self, package_id=None, dry_run=False):
+    def upgrade(self, package_id=None):
         """Perform the upgrade of the provided package to latest version."""
-        try:
-            upgrade_cli = self.upgrade_cli(package_id)
-        except NotImplementedError:
-            logger.warning(f"Upgrade not implemented for {self.id}.")
-            return
-        return self.run(upgrade_cli, dry_run=dry_run)
+        return self.run(self.upgrade_cli(package_id))
 
     def upgrade_all_cli(self):
         """Return a shell-compatible full-CLI to upgrade all packages."""
         raise NotImplementedError
 
-    def upgrade_all(self, dry_run=False):
+    def upgrade_all(self):
         """Perform a full upgrade of all outdated packages to latest versions.
 
         If the manager doesn't implements a full upgrade one-liner, then
         fall-back to calling single-package upgrade one by one.
         """
         try:
-            return self.run(self.upgrade_all_cli(), dry_run=dry_run)
+            return self.run(self.upgrade_all_cli())
         except NotImplementedError:
-            logger.warning(
-                f"Full upgrade subcommand not implemented in {self.id}. Call "
-                "single-package upgrade CLI one by one."
-            )
+            logger.warning(f"{self.id} does not implement upgrade_all command.")
+            logger.info(f"Call single-package upgrade CLI one by one.")
             log = []
             for package_id in self.outdated:
-                output = self.upgrade(package_id, dry_run=dry_run)
+                output = self.upgrade(package_id)
                 if output:
                     log.append(output)
             if log:
