@@ -32,14 +32,14 @@ import tomli_w
 from boltons.cacheutils import LRI, cached
 from boltons.strutils import complement_int_list, int_ranges_from_int_list, strip_ansi
 from cli_helpers.tabular_output import TabularOutputFormatter
-from click_help_colors import HelpColorsCommand, HelpColorsGroup, version_option
+from click_help_colors import version_option
 from simplejson import dumps as json_dumps
 
 from . import CLI_NAME, __version__, env_data, logger, reset_logger
-from .base import CLI_FORMATS, CLIError, PackageManager
+from .base import CLI_FORMATS, PackageManager
 from .config import load_conf
-from .managers import pool
-from .platform import CURRENT_OS_ID, WINDOWS, os_label
+from .managers import pool, select_managers
+from .platform import os_label
 from .version import TokenizedString
 
 # Initialize the table formatter.
@@ -51,25 +51,6 @@ RENDERING_MODES = {"json"}
 RENDERING_MODES.update(table_formatter.supported_formats)
 RENDERING_MODES = frozenset(RENDERING_MODES)
 
-# List of unicode rendering modes that will fall back to ascii on windows.
-# Windows has some hard time printing unicode characters to console output. It
-# seems to be an effect of cp1252 encoding and/or click not able to transcode
-# chars. Here is the traceback:
-#
-# File "(...)\meta_package_manager\cli.py", line 133, in print_table
-#   click.echo(line)
-# File "(...)\site-packages\click\utils.py", line 272, in echo
-#   file.write(message)
-# File "(...)\lib\encodings\cp1252.py", line 19, in encode
-#   return codecs.charmap_encode(input,self.errors,encoding_table)[0]
-# UnicodeEncodeError: 'charmap' codec can't encode characters in position
-#   0-140: character maps to <undefined>
-#
-# Fortunately, I found the fundamental issue and I no longer need to blacklist
-# some rendering modes. See: a3008f8c3a42efedd88378f087202b73d907bbb7 . I'll
-# still keep the construct around just in case I need to quickly blacklist
-# some.
-WINDOWS_MODE_BLACKLIST = frozenset([])
 
 # List of fields IDs allowed to be sorted.
 SORTABLE_FIELDS = {
@@ -80,6 +61,7 @@ SORTABLE_FIELDS = {
     "version",
 }
 
+
 # Pre-rendered UI-elements.
 OK = click.style("✓", fg="green")
 KO = click.style("✘", fg="red")
@@ -247,6 +229,13 @@ class timeit:
     default=False,
     help="Stop right away or continue operations on manager CLI error.",
 )
+@click.option(
+    "-d",
+    "--dry-run",
+    is_flag=True,
+    default=False,
+    help="Do not actually perform any action, just simulate CLI calls.",
+)
 @click.option(
     "-C",
     "--config",
@@ -286,6 +275,7 @@ def cli(
     stats,
     time,
     stop_on_error,
+    dry_run,
 ):
     """CLI for multi-package manager upgrades."""
 
@@ -294,21 +284,16 @@ def cli(
     level_name = logging._levelToName.get(level, level)
     logger.debug(f"Verbosity set to {level_name}.")
 
-    # Target all available managers by default.
-    target_ids = set(pool())
-    # Only keeps the subset selected by the user.
-    if manager:
-        target_ids = target_ids.intersection(manager)
-    # Remove managers excluded by the user.
-    target_ids = target_ids.difference(exclude)
-    target_managers = [pool()[mid] for mid in sorted(target_ids)]
-
-    # Apply manager-level options.
-    for m_obj in target_managers:
+    # Select the subset of manager to target, and apply manager-level options.
+    target_managers = select_managers(
+        keep=manager,
+        drop=exclude,
         # Does the manager should raise on error or not.
-        m_obj.stop_on_error = stop_on_error
+        stop_on_error=stop_on_error,
         # Should we include auto-update packages or not?
-        m_obj.ignore_auto_updates = ignore_auto_updates
+        ignore_auto_updates=ignore_auto_updates,
+        dry_run=dry_run,
+    )
 
     # Pre-filters inactive managers.
     def keep_available(manager):
@@ -326,11 +311,6 @@ def cli(
 
     # Setup the table formatter.
     if output_format != "json":
-
-        # Fallback unicode-rendering to safe ascii on Windows.
-        if CURRENT_OS_ID == WINDOWS and output_format in WINDOWS_MODE_BLACKLIST:
-            output_format = "ascii"
-
         table_formatter.format_name = output_format
 
     # Load up global options to the context.
@@ -539,10 +519,18 @@ def search(ctx, extended, exact, query):
     matches = {}
 
     for manager in active_managers:
+
+        # Allow managers to not implement search.
+        try:
+            results = manager.search(query, extended, exact).values()
+        except NotImplementedError:
+            logger.warning(f"{manager.id} does not implement search command.")
+            continue
+
         matches[manager.id] = {
             "id": manager.id,
             "name": manager.name,
-            "packages": list(manager.search(query, extended, exact).values()),
+            "packages": list(results),
         }
 
         # Serialize errors at the last minute to gather all we encountered.
@@ -588,7 +576,7 @@ def search(ctx, extended, exact, query):
         for i, j in sorted(bold_ranges + normal_ranges):
             segment = getitem(string, slice(i, j + 1))
             if (i, j) in bold_ranges:
-                segment = click.style(segment, bold=True)
+                segment = click.style(segment, bold=True, fg="green")
             styled_str += segment
 
         return styled_str
@@ -669,7 +657,12 @@ def outdated(ctx, cli_format):
 
     for manager in active_managers:
 
-        packages = list(map(dict, manager.outdated.values()))
+        try:
+            packages = list(map(dict, manager.outdated.values()))
+        except NotImplementedError:
+            logger.warning(f"{manager.id} does not implement outdated command.")
+            continue
+
         for info in packages:
             info.update({"upgrade_cli": render_cli(manager.upgrade_cli(info["id"]))})
 
@@ -732,27 +725,19 @@ def outdated(ctx, cli_format):
 
 
 @cli.command(short_help="Upgrade all packages.")
-@click.option(
-    "-d",
-    "--dry-run",
-    is_flag=True,
-    default=False,
-    help="Do not actually perform any upgrade, just simulate CLI calls.",
-)
 @click.pass_context
 @timeit()
-def upgrade(ctx, dry_run):
+def upgrade(ctx):
     """Perform a full package upgrade on all available managers."""
     active_managers = ctx.obj["active_managers"]
 
     for manager in active_managers:
-
         logger.info(f"Updating all outdated packages from {manager.id}...")
-
         try:
-            output = manager.upgrade_all(dry_run=dry_run)
-        except CLIError as expt:
-            logger.error(expt.error)
+            output = manager.upgrade_all()
+        except NotImplementedError:
+            logger.warning(f"{manager.id} does not implement upgrade command.")
+            continue
 
         if output:
             logger.info(output)
@@ -796,20 +781,16 @@ def backup(ctx, toml_output):
     # Create one section for each package manager.
     for manager in active_managers:
         logger.info(f"Dumping packages from {manager.id}...")
+        installed_packages = manager.installed.values()
 
         # Prepare data for stats.
         installed_data[manager.id] = {
             "id": manager.id,
-            "packages": manager.installed.values(),
+            "packages": installed_packages,
         }
 
         pkg_data = dict(
-            sorted(
-                [
-                    (p["id"], str(p["installed_version"]))
-                    for p in manager.installed.values()
-                ]
-            )
+            sorted([(p["id"], str(p["installed_version"])) for p in installed_packages])
         )
 
         if pkg_data:
@@ -846,7 +827,7 @@ def restore(ctx, toml_files):
         if ignored_sections:
             plural = "s" if len(ignored_sections) > 1 else ""
             sections = ", ".join(ignored_sections)
-            logger.warning(f"Ignore {sections} section{plural}.")
+            logger.info(f"Ignore {sections} section{plural}.")
 
         for manager in active_managers:
             if manager.id not in doc:
