@@ -29,19 +29,12 @@ class Flatpak(PackageManager):
 
     requirement = "1.2.0"
 
-    def get_version(self):
-        """Fetch version from ``flatpak --version`` output.
+    version_regex = r"Flatpak\s+(?P<version>\S+)"
+    """.. code-block:: shell-session
 
-        Raw CLI output samples:
-
-        .. code-block:: shell-session
-
-            ► flatpak --version
-            Flatpak 1.4.2
-        """
-        output = self.run_cli("--version")
-        if output:
-            return parse_version(output.strip().split()[1])
+        ► flatpak --version
+        Flatpak 1.4.2
+    """
 
     @property
     def installed(self):
@@ -181,8 +174,7 @@ class Flatpak(PackageManager):
                 if match:
                     name, package_id, latest_version = match.groups()
 
-                    info_installed_output = self.run(
-                        self.cli_path,
+                    info_installed_output = self.run_cli(
                         self.global_args,
                         "info",
                         "--ostree-verbose",
