@@ -33,9 +33,12 @@ class MAS(PackageManager):
 
     name = "Mac AppStore"
 
-    def get_version(self):
-        """Fetch version from ``mas version`` output."""
-        return parse_version(self.run_cli("version"))
+    version_cli_options = ["version"]
+    """.. code-block:: shell-session
+
+        ► mas version
+        1.8.3
+    """
 
     @property
     def installed(self):
