@@ -31,7 +31,13 @@ class NPM(PackageManager):
 
     name = "Node's npm"
 
-    def run_cli(self, *args, dry_run=False):
+    """.. code-block:: shell-session
+
+        ► npm --version
+        6.13.7
+    """
+
+    def run_cli(self, *args, force_exec=False):
         """Like the common run_cli helper, but silence NPM's JSON output on error.
 
         NPM is prone to breakage if local node version is not in sync:
@@ -47,7 +53,7 @@ class NPM(PackageManager):
               }
             }
         """
-        output = super().run_cli(*args, dry_run=dry_run)
+        output = super().run_cli(*args, force_exec=force_exec)
 
         # NPM fatal errors are reported both in <stderr> output and as JSON. So we
         # silence the errors in JSON so they get reported in CLI output (as
@@ -59,18 +65,6 @@ class NPM(PackageManager):
 
         return output
 
-    def get_version(self):
-        """Fetch version from ``npm --version`` output.
-
-        Raw CLI output samples:
-
-        .. code-block:: shell-session
-
-            ► npm --version
-            6.13.7
-        """
-        return parse_version(self.run_cli("--version"))
-
     @property
     def installed(self):
         """Fetch installed packages from ``npm list`` output.
