@@ -34,15 +34,11 @@ class Yarn(PackageManager):
 
     requirement = "1.21.0"
 
-    def get_version(self):
-        """Fetch version from ``yarn --version`` output.
+    """.. code-block:: shell-session
 
-        .. code-block:: shell-session
-
-            ► yarn --version
-            (...)
-        """
-        return parse_version(self.run_cli("--version"))
+        ► yarn --version
+        1.22.11
+    """
 
     def parse(self, output):
         packages = {}
@@ -194,7 +190,7 @@ class Yarn(PackageManager):
 
     @cachedproperty
     def global_dir(self):
-        return self.run_cli("global", "dir").rstrip()
+        return self.run_cli("global", "dir", force_exec=True).rstrip()
 
     def install(self, package_id):
         """Install one package.
