@@ -18,16 +18,14 @@
 import re
 from pathlib import Path
 
-import click
 import pytest
 import simplejson as json
 from boltons.iterutils import flatten
 from boltons.strutils import strip_ansi
-from cli_helpers.tabular_output import TabularOutputFormatter
 
 from .. import __version__, config
-from ..cli import RENDERING_MODES, WINDOWS_MODE_BLACKLIST
-from .conftest import MANAGER_IDS, unless_windows
+from ..cli import RENDERING_MODES
+from .conftest import MANAGER_IDS
 
 """ Common tests for all CLI basic features and templates for subcommands. """
 
@@ -199,19 +197,6 @@ class TestBaseCLI:
         assert "info: " not in result.stderr
         assert "debug: " not in result.stderr
 
-    @unless_windows
-    @pytest.mark.parametrize("mode", WINDOWS_MODE_BLACKLIST)
-    def test_check_failing_unicode_rendering(self, mode):
-        """Check internal assumption that some rendering unicode table
-        rendering modes fails in Windows console."""
-        table_formatter = TabularOutputFormatter(mode)
-        with pytest.raises(UnicodeEncodeError):
-            click.echo(
-                table_formatter.format_output(
-                    ((1, 87), (2, 80), (3, 79)), ("day", "temperature")
-                )
-            )
-
 
 class CLISubCommandTests:
 
@@ -261,7 +246,9 @@ class CLISubCommandTests:
                 # Common "not implemented" optional command warning message.
                 bool(
                     re.search(
-                        fr"warning: (Sync|Cleanup|Search) not implemented for {mid}.",
+                        fr"warning: {mid} does not implement "
+                        r"(search|outdated|upgrade|sync|cleanup|install|upgrade_all) "
+                        "command.",
                         result.stderr,
                     )
                 ),
@@ -449,7 +436,7 @@ class CLITableTests:
             assert expected in result.stdout
 
         # Collect all possible unique traces from all possible rendering modes.
-        blacklist = {
+        unexpected_traces = {
             v[0]
             for v in self.expected_renderings.values()
             # Exclude obvious character sequences shorter than 3 characters to
@@ -458,9 +445,9 @@ class CLITableTests:
         }
         # Remove overlapping edge-cases.
         if conflict:
-            blacklist.remove(self.expected_renderings[conflict][0])
+            unexpected_traces.remove(self.expected_renderings[conflict][0])
 
-        for unexpected in blacklist:
+        for unexpected in unexpected_traces:
             if unexpected != expected:
                 # The unexpected trace is not the selected one, it should not
                 # appears at all in stdout.
